@@ -385,7 +385,10 @@ class ctable(object):
             if sclist and not hasattr(column, '__len__'):
                 clen2 = 1
             else:
-                clen2 = 1 if isinstance(column, _strtypes) else len(column)
+                if isinstance(column, _strtypes):
+                    clen2 = 1
+                else:
+                    clen2 = len(column)
             if clen >= 0 and clen != clen2:
                 raise ValueError(
                     "all cols in `cols` must have the same length")
@@ -469,7 +472,7 @@ class ctable(object):
         if name is None:
             name = "f%d" % pos
         else:
-            if type(name) != str:
+            if not isinstance(name, _strtypes):
                 raise ValueError("`name` must be a string")
         if name in self.names:
             raise ValueError("'%s' column already exists" % name)
@@ -536,7 +539,7 @@ class ctable(object):
         if name is not None and pos is not None:
             raise ValueError("you cannot specify both a `name` and a `pos`")
         if name:
-            if type(name) != str:
+            if not isinstance(name, _strtypes):
                 raise ValueError("`name` must be a string")
             if name not in self.names:
                 raise ValueError("`name` not found in columns")
@@ -703,10 +706,11 @@ class ctable(object):
             raise
 
         # Use the names in kwargs, or if not there, the names in Table
-        if 'names' in kwargs:
-            names = kwargs.pop('names')
-        else:
-            names = t.colnames
+        names = kwargs.pop('names') if 'names' in kwargs else t.colnames
+        # Add the `expectedlen` param if necessary
+        if 'expectedlen' not in kwargs:
+            kwargs['expectedlen'] = len(t)
+
         # Collect metadata
         dtypes = [t.dtype.fields[name][0] for name in names]
         cols = [np.zeros(0, dtype=dt) for dt in dtypes]
@@ -795,7 +799,8 @@ class ctable(object):
         filters = tb.Filters(complevel=cparams['clevel'],
                              shuffle=cparams['clevel'],
                              complib=cname)
-        t = f.create_table(f.root, nodepath[1:], self.dtype, filters=filters)
+        t = f.create_table(f.root, nodepath[1:], self.dtype, filters=filters,
+                           expectedrows=len(self))
         # Set the attributes
         for key, val in self.attrs:
             t.attrs[key] = val
@@ -842,7 +847,7 @@ class ctable(object):
         """
 
         # Check input
-        if type(expression) is str:
+        if isinstance(expression, _strtypes):
             # That must be an expression
             boolarr = self.eval(expression)
         elif hasattr(expression, "dtype") and expression.dtype.kind == 'b':
@@ -855,7 +860,7 @@ class ctable(object):
         if outcols is None:
             outcols = self.names
         else:
-            if type(outcols) not in (list, tuple, str):
+            if type(outcols) not in (list, tuple) + _strtypes:
                 raise ValueError("only list/str is supported for outcols")
             # Check name validity
             nt = namedtuple('_nt', outcols, verbose=False)
@@ -980,7 +985,7 @@ class ctable(object):
         if outcols is None:
             outcols = self.names
         else:
-            if type(outcols) not in (list, tuple, str):
+            if type(outcols) not in (list, tuple) + _strtypes:
                 raise ValueError("only list/str is supported for outcols")
             # Check name validity
             nt = namedtuple('_nt', outcols, verbose=False)
@@ -1075,7 +1080,7 @@ class ctable(object):
         elif type(key) is list:
             if len(key) == 0:
                 return np.empty(0, self.dtype)
-            strlist = all(isinstance(v, str) for v in key)
+            strlist = all(isinstance(v, _strtypes) for v in key)
             # Range of column names
             if strlist:
                 cols = [self.cols[name] for name in key]
