@@ -15,7 +15,7 @@ import tempfile
 import numpy as np
 from numpy.testing import assert_array_equal, assert_allclose
 from bcolz.tests.common import (
-        MayBeDiskTest, TestCase, unittest, skipUnless, SkipTest ) 
+        MayBeDiskTest, TestCase, unittest, skipUnless, SkipTest)
 import bcolz
 from bcolz.py2help import xrange, PY2
 from bcolz.py2help_tests import Mock
@@ -608,6 +608,33 @@ class getitemTest(MayBeDiskTest):
         assert_array_equal(t[:], ra[:],
                            "ctable values are not correct")
 
+    def test_unicode_colname(self):
+        """Testing __getitem__ with a unicode column name"""
+        N = 10
+        ra = np.fromiter(((i, i * 2.) for i in xrange(N)), dtype='i4,f8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        colname = u"f1"
+        # print "t->", `t[colname]`
+        # print "ra->", ra[colname]
+        assert_array_equal(t[colname][:], ra[colname],
+                           "ctable values are not correct")                          
+
+    def test_multi_unicode_colnames(self):
+        """Testing __getitem__ with a list of unicode column names"""
+        N = 10
+        ra = np.fromiter(((i, i * 2., i * 3)
+                          for i in xrange(N)), dtype='i4,f8,i8')
+        t = bcolz.ctable(ra, rootdir=self.rootdir)
+        colnames = [u"f0", u"f2"]
+        # For some version of NumPy (> 1.7) I cannot make use of
+        # ra[colnames]   :-/
+        ra2 = np.fromiter(((i, i * 3) for i in xrange(N)), dtype='i4,i8')
+        ra2.dtype.names = ('f0', 'f2')
+        # print "t->", `t[colnames]`
+        # print "ra2->", ra2
+        assert_array_equal(t[colnames][:], ra2,
+                           "ctable values are not correct")
+
 
 class getitemMemoryTest(getitemTest, TestCase):
     disk = False
@@ -1517,7 +1544,7 @@ class iterblocksTest(MayBeDiskTest):
         for block in bcolz.iterblocks(t, blen, blen - 1):
             l += len(block)
             # f8 is to small to hold the sum on 32 bit
-            s += block['f1'].sum(dtype='f16')
+            s += block['f1'].sum(dtype=np.longdouble)
         self.assertEqual(l, (N - (blen - 1)))
         self.assertEqual(s, (np.arange(blen - 1, N, dtype='f8') * 2).sum())
 
@@ -2261,9 +2288,8 @@ class ContextManagerTest(MayBeDiskTest, TestCase):
 
 class ImportTest(TestCase):
 
-     @SkipTest 
+     @SkipTest
      def test_fork(self):
-            
         if os.name == 'posix':
             pid = os.fork()
             # terminate nose on child process
